================
Module reference
================

The **RunTask** modules defines one class realizing a coherent time task
scheduler with a set of methods for the control of excution timing of a set
of tasks.


Objects and methods
-------------------

.. currentmodule:: runtask
.. autoclass:: RunTask
   :special-members:
   :members:
   :exclude-members: runaln

.. automethod:: RunTask
